//
//  CreateUserTokenViewController.swift
//  SampleApp
//
//  Created by Nutchaphon Rewik on 3/5/2565 BE.
//  Copyright © 2565 BE David Zhang. All rights reserved.
//

import UIKit
import AmitySDK

class CreateUserTokenViewController: UIViewController {

    private var userTokenManager: AmityUserTokenManager?
    
    @IBOutlet private weak var scrollView: UIScrollView!
    @IBOutlet private weak var regionSegmentedControl: UISegmentedControl!
    @IBOutlet private weak var apiKeyTextField: UITextField!
    @IBOutlet private weak var userIdTextField: UITextField!
    @IBOutlet private weak var displayNameTextField: UITextField!
    @IBOutlet private weak var authTokenTextField: UITextField!
    @IBOutlet private weak var createUserTokenButton: UIButton!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        scrollView.contentInset.bottom = 500
        navigationItem.leftBarButtonItems = [
            UIBarButtonItem(barButtonSystemItem: .close, target: self, action: #selector(dismissButtonDidTouch))
        ]
    }
    
    convenience init() {
        self.init(nibName: "CreateUserTokenViewController", bundle: Bundle(for: CreateUserTokenViewController.self))
    }
    
    @objc private func dismissButtonDidTouch() {
        dismiss(animated: true, completion: nil)
    }
    
    @IBAction private func createUserTokenButtonDidTouch() {
        
        let apiKey = apiKeyTextField.text
        let region = getRegion()
        let userId = userIdTextField.text
        
        guard let apiKey = apiKey, !apiKey.isEmpty else {
            showAlert(message: "apiKey must not be empty.")
            return
        }
        
        guard let userId = userId, !userId.isEmpty else {
            showAlert(message: "userId must not be empty.")
            return
        }
        
        let displayName: String?
        if let _displayName = displayNameTextField.text, !_displayName.isEmpty {
            displayName = _displayName
        } else {
            displayName = nil
        }
        
        let authToken: String?
        if let _authToken = authTokenTextField.text, !_authToken.isEmpty {
            authToken = _authToken
        } else {
            authToken = nil
        }
        
        createUserTokenButton.isEnabled = false
        userTokenManager = AmityUserTokenManager(apiKey: apiKey, region: region)
        
        Task { @MainActor in
            do {
                let auth = try await userTokenManager!.createUserToken(userId: userId, displayName: displayName, authToken: authToken)
                UIPasteboard.general.string = auth.accessToken
                showAlert(message: "The access token is copied to pasteboard.")
            } catch {
                showAlert(message: error.localizedDescription)
            }
            createUserTokenButton.isEnabled = true
        }
        
    }
    
    private func getRegion() -> AmityRegion {
        let regions: [AmityRegion] = [.EU, .SG, .US]
        let region = regions[regionSegmentedControl.selectedSegmentIndex]
        return region
    }
    
    private func showAlert(message: String) {
        let alertController = UIAlertController(title: nil, message: message, preferredStyle: .alert)
        let ok = UIAlertAction(title: "OK", style: .default, handler: nil)
        alertController.addAction(ok)
        present(alertController, animated: true, completion: nil)
    }
    
}
